@@ -157,10 +157,13 @@ def install_hanlp_jar():
     jar_version, jar_url, data_version, data_url = hanlp_latest_version()
     jar_zip = os.path.join(STATIC_ROOT, 'hanlp-{}-release.zip'.format(jar_version))
     download(jar_url, jar_zip)
-    with zipfile.ZipFile(jar_zip, "r") as archive:
-        # for f in archive.namelist():
-        #     print(f)
-        archive.extract('hanlp-{}-release/hanlp-{}.jar'.format(jar_version, jar_version), STATIC_ROOT)
+    try:
+        with zipfile.ZipFile(jar_zip, "r") as archive:
+            archive.extract('hanlp-{}-release/hanlp-{}.jar'.format(jar_version, jar_version), STATIC_ROOT)
+    except zipfile.BadZipFile:
+        remove_file(jar_zip)
+        eprint('解压失败，请重试')
+        exit(1)
     zip_folder = os.path.join(STATIC_ROOT, 'hanlp-{}-release'.format(jar_version))
     jar_file_name = 'hanlp-{}.jar'.format(jar_version)
     os.rename(os.path.join(zip_folder, jar_file_name), os.path.join(STATIC_ROOT, jar_file_name))
@@ -203,8 +206,13 @@ def install_hanlp_data(the_jar_version=None):
             data_zip = os.path.join(STATIC_ROOT, data_zip)
             download(data_url, os.path.join(STATIC_ROOT, data_zip))
             eprint('解压 data.zip...')
-            with zipfile.ZipFile(data_zip, "r") as zip_ref:
-                zip_ref.extractall(STATIC_ROOT)
+            try:
+                with zipfile.ZipFile(data_zip, "r") as zip_ref:
+                    zip_ref.extractall(STATIC_ROOT)
+            except zipfile.BadZipFile:
+                remove_file(data_zip)
+                eprint('解压失败，请重试')
+                exit(1)
             os.remove(data_zip)
             write_config(root=STATIC_ROOT)
             with open_(PATH_DATA_VERSION, 'w', encoding='utf-8') as f:
